@@ -3,7 +3,7 @@ package Log::Dispatch::Email::MIMELite;
 use strict;
 use warnings;
 
-our $VERSION = '2.60';
+our $VERSION = '2.61';
 
 use MIME::Lite;
 
@@ -22,7 +22,7 @@ sub send_email {
 
     $mail{From} = $self->{from} if defined $self->{from};
 
-    local $? = undef;
+    local $? = 0;
     unless ( MIME::Lite->new(%mail)->send ) {
         warn 'Error sending mail with MIME::Lite';
     }
@@ -44,7 +44,7 @@ Log::Dispatch::Email::MIMELite - Subclass of Log::Dispatch::Email that uses the
 
 =head1 VERSION
 
-version 2.60
+version 2.61
 
 =head1 SYNOPSIS
 
