@@ -3,7 +3,7 @@ package Log::Dispatch::Email::MailSend;
 use strict;
 use warnings;
 
-our $VERSION = '2.60';
+our $VERSION = '2.61';
 
 use Mail::Send;
 use Try::Tiny;
@@ -22,7 +22,7 @@ sub send_email {
     # Does this ever work for this module?
     $msg->set( 'From', $self->{from} ) if $self->{from};
 
-    local $? = undef;
+    local $? = 0;
     return
         if try {
         my $fh = $msg->open
@@ -56,7 +56,7 @@ Log::Dispatch::Email::MailSend - Subclass of Log::Dispatch::Email that uses the
 
 =head1 VERSION
 
-version 2.60
+version 2.61
 
 =head1 SYNOPSIS
 
