@@ -3,7 +3,7 @@ package Log::Dispatch::Output;
 use strict;
 use warnings;
 
-our $VERSION = '2.60';
+our $VERSION = '2.61';
 
 use Carp ();
 use Log::Dispatch;
@@ -23,8 +23,12 @@ sub new {
 {
     my $validator = validation_for(
         params => {
-            level   => { type => t('LogLevel') },
-            message => { type => t('NonEmptyStr') },
+            level => { type => t('LogLevel') },
+
+            # Pre-PVC we accepted empty strings, which is weird, but we don't
+            # want to break back-compat. See
+            # https://github.com/houseabsolute/Log-Dispatch/issues/38.
+            message => { type => t('Str') },
         },
         slurpy => 1,
     );
@@ -199,7 +203,7 @@ Log::Dispatch::Output - Base class for all Log::Dispatch::* objects
 
 =head1 VERSION
 
-version 2.60
+version 2.61
 
 =head1 SYNOPSIS
 
