@@ -3,7 +3,7 @@ package Log::Dispatch::Syslog;
 use strict;
 use warnings;
 
-our $VERSION = '2.60';
+our $VERSION = '2.61';
 
 use Log::Dispatch::Types;
 use Params::ValidationCompiler qw( validation_for );
@@ -21,7 +21,10 @@ my $thread_lock;
     my $validator = validation_for(
         params => {
             ident => {
-                type    => t('NonEmptyStr'),
+
+                # It's weird to allow an empty string but that's how this
+                # worked pre-PVC.
+                type    => t('Str'),
                 default => $DefaultIdent
             },
             logopt => {
@@ -134,7 +137,7 @@ Log::Dispatch::Syslog - Object for logging to system log.
 
 =head1 VERSION
 
-version 2.60
+version 2.61
 
 =head1 SYNOPSIS
 
